[Jboss-cvs] JBossAS SVN: r55475 - branches/MC_VDF_WORK/system-jmx/src/main/org/jboss/system/server

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Wed Aug 9 23:26:27 EDT 2006


Author: scott.stark at jboss.org
Date: 2006-08-09 23:26:25 -0400 (Wed, 09 Aug 2006)
New Revision: 55475

Modified:
   branches/MC_VDF_WORK/system-jmx/src/main/org/jboss/system/server/ServerConfigImpl.java
Log:
Use the ServerConfig interface as the delegate

Modified: branches/MC_VDF_WORK/system-jmx/src/main/org/jboss/system/server/ServerConfigImpl.java
===================================================================
--- branches/MC_VDF_WORK/system-jmx/src/main/org/jboss/system/server/ServerConfigImpl.java	2006-08-10 03:22:14 UTC (rev 55474)
+++ branches/MC_VDF_WORK/system-jmx/src/main/org/jboss/system/server/ServerConfigImpl.java	2006-08-10 03:26:25 UTC (rev 55475)
@@ -22,7 +22,6 @@
 package org.jboss.system.server;
 
 import java.io.File;
-import java.net.MalformedURLException;
 import java.net.URL;
 
 /**
@@ -35,15 +34,15 @@
 public class ServerConfigImpl
       implements ServerConfigImplMBean
 {
-   private BaseServerConfig config;
+   private ServerConfig config;
 
    /**
     * Construct a ServerConfigImpl with the BaseServerConfig which will be used
     * as the delegate for the ServerConfigImplMBean ops.
     *
     * @param config - the BaseServerConfig pojo to expose as a ServerConfigImplMBean
     */
-   public ServerConfigImpl(BaseServerConfig config)
+   public ServerConfigImpl(ServerConfig config)
    {
       this.config = config;
    }
@@ -168,11 +167,6 @@
       return config.hashCode();
    }
 
-   public void initURLs() throws MalformedURLException
-   {
-      config.initURLs();
-   }
-
    public void setBlockingShutdown(boolean flag)
    {
       config.setBlockingShutdown(flag);
@@ -35,15 +34,15 @@
 
    /**
-    * Construct a ServerConfigImpl with the BaseServerConfig which will be used
+    * Construct a ServerConfigImpl with the ServerConfig pojo which will be used
     * as the delegate for the ServerConfigImplMBean ops.
     *
@@ -35,15 +34,15 @@
     * as the delegate for the ServerConfigImplMBean ops.
     *
-    * @param config - the BaseServerConfig pojo to expose as a ServerConfigImplMBean
+    * @param config - the ServerConfig pojo to expose as a ServerConfigImplMBean
     */




More information about the jboss-cvs-commits mailing list